=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-01-18 03:09:39 +0000
+++ bzrlib/branch.py	2006-01-24 21:43:46 +0000
@@ -63,10 +63,6 @@
 # cache in memory to make this faster.  In general anything can be
 # cached in memory between lock and unlock operations.
 
-# FIXME: At the moment locking the Branch locks both the repository and the
-# control files, representing the two aspects currently controlled by one
-# object.  However, they currently both map to the same lockfile. 
-
 def find_branch(*ignored, **ignored_too):
     # XXX: leave this here for about one release, then remove it
     raise NotImplementedError('find_branch() is not supported anymore, '
@@ -133,6 +129,8 @@
         """Subclasses that care about caching should override this, and set
         up cached stores located under cache_root.
         """
+        # seems to be unused, 2006-01-13 mbp
+        warn('%s is deprecated' % self.setup_caching)
         self.cache_root = cache_root
 
     def _get_nick(self):
@@ -161,7 +159,7 @@
 
     def peek_lock_mode(self):
         """Return lock mode for the Branch: 'r', 'w' or None"""
-        raise NotImplementedError(self.is_locked)
+        raise NotImplementedError(self.peek_lock_mode)
 
     def abspath(self, name):
         """Return absolute filename for something in the branch
@@ -378,6 +376,9 @@
         to_branch_type
             Branch type of destination branch
         """
+        # circular import protection
+        from bzrlib.merge import build_working_dir
+
         assert isinstance(to_location, basestring)
         if not bzrlib.osutils.lexists(to_location):
             os.mkdir(to_location)
@@ -392,8 +393,6 @@
             revision = self.last_revision()
         br_to.update_revisions(self, stop_revision=revision)
         br_to.set_parent(self.base)
-        # circular import protection
-        from bzrlib.merge import build_working_dir
         build_working_dir(to_location)
         mutter("copied")
         return br_to
@@ -479,6 +478,7 @@
         # Alternatively, we could have the Transport objects cache requests
         # See the earlier discussion about how major objects (like Branch)
         # should never expect their __del__ function to run.
+        # XXX: cache_root seems to be unused, 2006-01-13 mbp
         if hasattr(self, 'cache_root') and self.cache_root is not None:
             try:
                 shutil.rmtree(self.cache_root)

=== modified file 'bzrlib/decorators.py'
--- bzrlib/decorators.py	2006-01-18 03:09:39 +0000
+++ bzrlib/decorators.py	2006-01-24 21:43:46 +0000
@@ -38,6 +38,8 @@
             return unbound(self, *args, **kwargs)
         finally:
             self.unlock()
+    decorated.__doc__ = unbound.__doc__
+    decorated.__name__ = unbound.__name__
     return decorated
 
 
@@ -49,5 +51,7 @@
             return unbound(self, *args, **kwargs)
         finally:
             self.unlock()
+    decorated.__doc__ = unbound.__doc__
+    decorated.__name__ = unbound.__name__
     return decorated
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-01-12 08:48:59 +0000
+++ bzrlib/tests/__init__.py	2006-01-13 06:38:56 +0000
@@ -692,6 +692,7 @@
                    'bzrlib.tests.test_config',
                    'bzrlib.tests.test_conflicts',
                    'bzrlib.tests.test_diff',
+                   'bzrlib.tests.test_decorators',
                    'bzrlib.tests.test_fetch',
                    'bzrlib.tests.test_gpg',
                    'bzrlib.tests.test_graph',

=== added file 'bzrlib/tests/test_decorators.py'
--- bzrlib/tests/test_decorators.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_decorators.py	2006-01-13 06:38:56 +0000
@@ -0,0 +1,44 @@
+# Copyright (C) 2006 Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Tests for decorator functions"""
+
+from bzrlib.decorators import needs_read_lock
+from bzrlib.tests import TestCase
+
+
+class DecoratorSample(object):
+    """Sample class that uses decorators.
+
+    This doesn't actually work because the class doesn't have the 
+    requiste lock_read()/unlock() methods.
+    """
+
+    @needs_read_lock
+    def frob(self):
+        """Frob the sample object"""
+
+
+class TestDecoratorDocs(TestCase):
+    """Test method decorators"""
+
+    def test_read_lock_passthrough(self):
+        """@needs_read_lock exposes underlying name and doc."""
+        sam = DecoratorSample()
+        self.assertEqual(sam.frob.__name__, 'frob')
+        self.assertEqual(sam.frob.__doc__, 
+                'Frob the sample object')

